@@ -4,7 +4,7 @@ import functools
 import hashlib
 import logging
 import uuid as _uuid
-from typing import Any, Optional, Literal, Dict, Callable, Tuple
+from typing import Any, Optional, Literal, Dict, Callable, Tuple, List, Union
 from urllib.parse import urlencode, unquote
 
 import jwt
@@ -37,10 +37,10 @@ from .models import (
 
 class Upbit:
     def __init__(self,
-                 access_key: str | None = None,
-                 secret_key: str | None = None,
-                 http_adapter: HTTPAdapter | None = None,
-                 timeout: float | Tuple[float, float] | Tuple[float, None] | None = None,
+                 access_key: Optional[str] = None,
+                 secret_key: Optional[str] = None,
+                 http_adapter: Optional[HTTPAdapter] = None,
+                 timeout: Union[float, Tuple[float, float], Tuple[float, None]] = None,
                  ):
         """
         :param access_key: 업비트 API Access Key
@@ -178,7 +178,7 @@ class Upbit:
             self._logger.warning(f"Upbit API 잔여 요청수 처리 에러. {remaining_req=!r} {e!r}")
             pass
 
-    def _get_request_headers(self, query: Dict = None, headers: Dict | None = None) -> Dict:
+    def _get_request_headers(self, query: dict = None, headers: dict = None) -> Dict:
         """인증 헤더를 만들어 반환한다.
 
         :param query: 요청 바디
@@ -403,11 +403,11 @@ class Upbit:
 
     def get_orders(self,
                    *,
-                   market: Optional[str] = None,
-                   uuids: Optional[list[str]] = None,
-                   identifiers: Optional[list[str]] = None,
+                   market: str = None,
+                   uuids: List[str] = None,
+                   identifiers: List[str] = None,
                    state: OrderState = 'wait',
-                   states: Optional[list[OrderState]] = None,
+                   states: List[OrderState] = None,
                    page: int = 1,
                    limit: int = 100,
                    order_by: OrderBy = 'desc',
@@ -474,8 +474,8 @@ class Upbit:
     def get_orders_by_id(self,
                          *,
                          market: Optional[str] = None,
-                         uuids: Optional[list[str]] = None,
-                         identifiers: Optional[list[str]] = None,
+                         uuids: Optional[List[str]] = None,
+                         identifiers: Optional[List[str]] = None,
                          order_by: OrderBy = 'desc',
                          **kwargs) -> Response:
         """id로 주문리스트 조회
@@ -535,7 +535,7 @@ class Upbit:
                         *,
                         market: Optional[str] = None,
                         state: OpenOrderState = 'wait',
-                        states: Optional[list[OpenOrderState]] = None,
+                        states: Optional[List[OpenOrderState]] = None,
                         page: int = 1,
                         limit: int = 100,
                         order_by: OrderBy = 'desc',
@@ -601,9 +601,9 @@ class Upbit:
                           *,
                           market: Optional[str] = None,
                           state: ClosedOrderState = 'done',
-                          states: Optional[list[ClosedOrderState]] = None,
-                          start_time: str | None = None,
-                          end_time: str | None = None,
+                          states: Optional[List[ClosedOrderState]] = None,
+                          start_time: Optional[str] = None,
+                          end_time: Optional[str] = None,
                           limit: int = 100,
                           order_by: OrderBy = 'desc',
                           **kwargs) -> Response:
@@ -795,8 +795,8 @@ class Upbit:
                       *,
                       currency: Optional[str] = None,
                       state: Optional[WithdrawState] = None,
-                      uuids: Optional[list[str]] = None,
-                      txids: Optional[list[str]] = None,
+                      uuids: Optional[List[str]] = None,
+                      txids: Optional[List[str]] = None,
                       page: int = 1,
                       limit: int = 100,
                       order_by: OrderBy = 'desc',
@@ -940,7 +940,7 @@ class Upbit:
                     "email_verified": true,
                     "identity_auth_verified": true,
                     "bank_account_verified": true,
-                    "kakao_pay_auth_verified": false,
+                    "two_factor_auth_verified": true,
                     "locked": false,
                     "wallet_locked": false
                 },
@@ -964,13 +964,16 @@ class Upbit:
                 },
                 "withdraw_limit": {
                     "currency": "BTC",
-                    "minimum": null,
+                    "minimum": "0.001",
                     "onetime": null,
                     "daily": "10.0",
                     "remaining_daily": "10.0",
                     "remaining_daily_krw": "0.0",
-                    "fixed": null,
-                    "can_withdraw": true
+                    "remaining_daily_fiat": "0.0",
+                    "fiat_currency": "KRW",
+                    "withdraw_delayed_fiat": "0.0",
+                    "fixed": 8,
+                    "can_withdraw": true,
                 }
             }
         """
@@ -1135,8 +1138,8 @@ class Upbit:
                      *,
                      currency: Optional[str] = None,
                      state: Optional[DepositState] = None,
-                     uuids: Optional[list[str]] = None,
-                     txids: Optional[list[str]] = None,
+                     uuids: Optional[List[str]] = None,
+                     txids: Optional[List[str]] = None,
                      page: int = 1,
                      limit: int = 100,
                      order_by: OrderBy = 'desc',
@@ -1698,6 +1701,52 @@ class Upbit:
 
         return self._request('get', url, params=params, **kwargs)
 
+    def get_candles_second(self,
+                           market: str,
+                           *,
+                           to: Optional[str] = None,
+                           count: Optional[int] = None,
+                           **kwargs) -> Response:
+        """초(Second) 캔들 조회
+
+        API 요청 및 응답에 대한 자세한 정보는 공식 문서 참고:
+        `Upbit API Doc <https://docs.upbit.com/reference/%EC%B4%88second-%EC%BA%94%EB%93%A4>`_
+
+        :param market: 마켓 코드 (ex. KRW-BTC)
+        :param to: 마지막 캔들 시각 (exclusive). 포맷 : yyyy-MM-dd'T'HH:mm:ss'Z' or yyyy-MM-dd HH:mm:ss. 비워서 요청시 가장 최근 캔들
+        :param count: 캔들 개수. 최대 200
+        :param kwargs: `requests.Session.request` 호출에 사용할 파라미터
+
+        :return: API 서버 응답
+
+        Usage::
+
+            upbit = Upbit()
+            res = upbit.get_candles_second('KRW-BTC')
+            print(res.json())
+
+            [{
+                "market": "KRW-BTC",
+                "candle_date_time_utc": "2024-07-30T09:32:41",
+                "candle_date_time_kst": "2024-07-30T18:32:41",
+                "opening_price": 93557000,
+                "high_price": 93557000,
+                "low_price": 93551000,
+                "trade_price": 93551000,
+                "timestamp": 1722331961297,
+                "candle_acc_trade_price": 485957.73742,
+                "candle_acc_trade_volume": 0.0051944
+            }, ...]
+        """
+        url = self._endpoint + "/candles/seconds/"
+        params = {
+            "market": market,
+            "to": to,
+            "count": count,
+        }
+
+        return self._request('get', url, params=params, **kwargs)
+
     def get_candles_day(self,
                         market: str,
                         *,
@@ -1845,6 +1894,53 @@ class Upbit:
 
         return self._request('get', url, params=params, **kwargs)
 
+    def get_candles_year(self,
+                         market: str,
+                         *,
+                         to: Optional[str] = None,
+                         count: Optional[int] = None,
+                         **kwargs) -> Response:
+        """연(Year) 캔들 조회
+
+        API 요청 및 응답에 대한 자세한 정보는 공식 문서 참고:
+        `Upbit API Doc <https://docs.upbit.com/reference/%EB%85%84year-%EC%BA%94%EB%93%A4>`_
+
+        :param market: 마켓 코드 (ex. KRW-BTC)
+        :param to: 마지막 캔들 시각 (exclusive). 포맷 : yyyy-MM-dd'T'HH:mm:ss'Z' or yyyy-MM-dd HH:mm:ss. 비워서 요청시 가장 최근 캔들
+        :param count: 캔들 개수. 최대 200
+        :param kwargs: `requests.Session.request` 호출에 사용할 파라미터
+
+        :return: API 서버 응답
+
+        Usage::
+
+            upbit = Upbit()
+            res = upbit.get_candles_second('KRW-BTC')
+            print(res.json())
+
+            [{
+                "market": "KRW-BTC",
+                "candle_date_time_utc": "2024-01-01T00:00:00",
+                "candle_date_time_kst": "2024-01-01T09:00:00",
+                "opening_price": 96290000,
+                "high_price": 1231356000,
+                "low_price": 124.5,
+                "trade_price": 85375000,
+                "timestamp": 1727845502277,
+                "candle_acc_trade_price": 60613272545.65653,
+                "candle_acc_trade_volume": 708.81714523,
+                "first_day_of_period": "2024-01-01"
+            }, ...]
+        """
+        url = self._endpoint + "/candles/years/"
+        params = {
+            "market": market,
+            "to": to,
+            "count": count,
+        }
+
+        return self._request('get', url, params=params, **kwargs)
+
     # --------------------------------------------------------------------------
     # Quotation API > 시세 체결 조회
     # --------------------------------------------------------------------------
@@ -1906,7 +2002,7 @@ class Upbit:
     # --------------------------------------------------------------------------
 
     def get_ticker(self,
-                   markets: list[str],
+                   markets: List[str],
                    **kwargs) -> Response:
         """현재가 정보 조회
 
@@ -1961,7 +2057,7 @@ class Upbit:
         return self._request('get', url, params=params, **kwargs)
 
     def get_tickers_by_quote(self,
-                             quotes: list[str],
+                             quotes: List[str],
                              **kwargs) -> Response:
         """마켓 단위 현재가 정보 조회
 
@@ -2020,7 +2116,7 @@ class Upbit:
     # --------------------------------------------------------------------------
 
     def get_orderbook(self,
-                      markets: [str],
+                      markets: List[str],
                       **kwargs) -> Response:
         """호가 정보 조회
 
